streamed_controller library

Classes

AsyncQueue<T>
ConcurrentConcurrencyHandler<State extends Object>
Handler that simultaneously process every event that comes from user asy
DebouncedDroppableConcurrencyHandler<State extends Object>
Additional handler over DroppableConcurrency Forces a controller to wait a debounceDuration before process stream Resets that Timer if user interupted timer with any event
DroppableConcurrencyHandler<State extends Object>
Handler that ignores the processing of all events if something else is being processed at the moment
HandlerBase<State extends Object>
Base for mutators that describes their lifecycle and main methods
RestartableConcurrencyHandler<State extends Object>
Restarts whole stream processing on any user interuption Warning: it will continue to work until the first yield It means that any futures will be completed, but ignored
SequentalConcurrentHandler<State extends Object>
SingleSubscriptionHandlerBase<State extends Object>
StatefulStreamedScope<T extends StreamedController<Object>>
Declarative scope that controls full flow of controller lifecycle
StreamedController<State extends Object>
Base class for all inherited controllers
StreamedControllerObserver
ControllerObserver Singleton class
StreamedScope<T extends StreamedController<Object>>
StreamedScope widget.
ThrottledDroppableConcurrencyHandler<State extends Object>
Additional transformer handler over DroppableConcurrency Throttling is used to process a stream after every throttleDuration Note: first event processed immediatly

Extensions

$DurationExt on Duration
ListenableSelectorExtension on Controller
Selects a specific value from the Listenable for subsequent use in the ValueListenableBuilder

Typedefs

ListenableFilter<Value> = bool Function(Value prev, Value next)
Filter for Listenable
ListenableSelector<Controller extends Listenable, Value> = Value Function(Controller controller)
Selector from Listenable